==> rapid_widgets_library-0.2.8.tar.gz: lib/custom-filepicker.dart <==
/*
Imports Required:
import 'package:flutter/material.dart';
import 'custom-filepicker.dart';

Widget can be parameterised as follows:
The widget allows you to select on or more files from the device as per parameters passed.
The selected files are shown below the button.


SAMPLE IMPLEMENTATION:

    CustomFilePicker fileobj = new CustomFilePicker(
        multiPick: true,
        title: "Select",
        color: Colors.red,
        textColor: Colors.white,
        buttonRadius:20.0);

body: Center(child: fileobj)

AUTHOR: Soumyadeep Mitra
*/

import 'dart:core';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:file_picker/file_picker.dart';

import 'package:rapid_widgets_library/consts.dart';

class CustomFilePicker extends StatefulWidget {
  final bool multiPick;
  final dynamic title;
  final Color color;
  final Color textColor;
  final double buttonRadius;

  const CustomFilePicker(
      {Key key,
      this.multiPick,
      this.title,
      this.color,
      this.textColor,
      this.buttonRadius})
      : super(key: key);
  @override
  CustomFilePickerState createState() => new CustomFilePickerState();
}

class CustomFilePickerState extends State<CustomFilePicker> {
  dynamic _fileName;
  dynamic _path;
  bool _multiPick;
  Map<dynamic, dynamic> _paths;
  dynamic _extension;
  bool _loadingPath = false;

  FileType _pickingType = FileType.any;
  TextEditingController _controller = new TextEditingController();

  @override
  void initState() {
    super.initState();
    _multiPick = widget.multiPick;
    _controller.addListener(() => _extension = _controller.text);
  }

  void _openFileExplorer() async {
    setState(() => _loadingPath = true);
    try {
      if (_multiPick) {
        _path = null;
        _paths = await FilePicker.platform.getMultiFilePath(
            type: _pickingType,
            allowedExtensions: (_extension?.isNotEmpty ?? false)
                ? _extension?.replaceAll(' ', '')?.split(',')
                : null);
      } else {
        _paths = null;
        _path = await FilePicker.getFilePath(
            type: _pickingType,
            allowedExtensions: (_extension?.isNotEmpty ?? false)
                ? _extension?.replaceAll(' ', '')?.split(',')
                : null);
      }
    } on PlatformException catch (e) {
      print("Unsupported operation" + e.toString());
    }
    if (!mounted) return;
    setState(() {
      _loadingPath = false;
      _fileName = _path != null
          ? _path.split('/').last
          : _paths != null
              ? _paths.keys.toString()
              : '...';
    });
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: new Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Container(
            child: new RaisedButton(
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(
                      widget.buttonRadius == null
                          ? heightTwenty
                          : widget.buttonRadius)),
              color: widget.color == null
                  ? Theme.of(context).accentColor
                  : widget.color,
              textColor: widget.textColor == null
                  ? Theme.of(context).primaryColorDark
                  : widget.textColor,
              onPressed: () => _openFileExplorer(),
              child: new Text(widget.title == null ? "Select" : widget.title),
            ),
          ),
          new Builder(
            builder: (BuildContext context) => _loadingPath
                ? Padding(
                    padding: const EdgeInsets.only(bottom: heightTen),
                    child: const CircularProgressIndicator())
                : _path != null || _paths != null
                    ? new Container(
                        padding: const EdgeInsets.only(bottom: heightThirty),
                        height: MediaQuery.of(context).size.height * 0.50,
                        child: new Scrollbar(
                            child: new ListView.separated(
                          itemCount: _paths != null && _paths.isNotEmpty
                              ? _paths.length
                              : 1,
                          itemBuilder: (BuildContext context, int index) {
                            final bool isMultiPath =
                                _paths != null && _paths.isNotEmpty;
                            final dynamic name = 'File $index: ' +
                                (isMultiPath
                                    ? _paths.keys.toList()[index]
                                    : _fileName ?? '...');
                            final path = isMultiPath
                                ? _paths.values.toList()[index].toString()
                                : _path;

                            return new ListTile(
                              title: new Text(
                                name,
                              ),
                              subtitle: new Text(path),
                            );
                          },
                          separatorBuilder: (BuildContext context, int index) =>
                              new Divider(),
                        )),
                      )
                    : new Container(),
          ),
        ],
      ),
    );
  }
}

==> rapid_widgets_library-0.2.38.tar.gz: lib/custom-filepicker.dart <==
/*
Imports Required:
import 'package:flutter/material.dart';
import 'custom-filepicker.dart';

Widget can be parameterised as follows:
The widget allows you to select on or more files from the device as per parameters passed.
The selected files are shown below the button.


SAMPLE IMPLEMENTATION:

    CustomFilePicker fileobj = new CustomFilePicker(
        multiPick: true,
        title: "Select",
        color: Colors.red,
        textColor: Colors.white,
        buttonRadius:20.0);

body: Center(child: fileobj)

AUTHOR: Soumyadeep Mitra
*/

import 'dart:core';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:file_picker/file_picker.dart';

import 'package:rapid_widgets_library/consts.dart';

class CustomFilePicker extends StatefulWidget {
  final bool multiPick;
  final dynamic title;
  final Color color;
  final Color textColor;
  final double buttonRadius;

  const CustomFilePicker(
      {Key key,
      this.multiPick,
      this.title,
      this.color,
      this.textColor,
      this.buttonRadius})
      : super(key: key);
  @override
  CustomFilePickerState createState() => new CustomFilePickerState();
}

class CustomFilePickerState extends State<CustomFilePicker> {
  dynamic _fileName;
  dynamic _path;
  bool _multiPick;
  Map<dynamic, dynamic> _paths;
  dynamic _extension;
  bool _loadingPath = false;

  FileType _pickingType = FileType.any;
  TextEditingController _controller = new TextEditingController();

  @override
  void initState() {
    super.initState();
    _multiPick = widget.multiPick;
    _controller.addListener(() => _extension = _controller.text);
  }

  void _openFileExplorer() async {
    setState(() => _loadingPath = true);
    try {
      // if (_multiPick) {
      //   _path = null;
      //   _paths = await FilePicker.platform.pickFiles(
      //       type: _pickingType,
      //       allowedExtensions: (_extension?.isNotEmpty ?? false)
      //           ? _extension?.replaceAll(' ', '')?.split(',')
      //           : null);
      // } else {
        _paths = null;
        _path = await FilePicker.platform.pickFiles(
            type: _pickingType,
            allowedExtensions: (_extension?.isNotEmpty ?? false)
                ? _extension?.replaceAll(' ', '')?.split(',')
                : null);
      //}
    } on PlatformException catch (e) {
      print("Unsupported operation" + e.toString());
    }
    if (!mounted) return;
    setState(() {
      _loadingPath = false;
      _fileName = _path != null
          ? _path.split('/').last
          : _paths != null
              ? _paths.keys.toString()
              : '...';
    });
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: new Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Container(
            child: new RaisedButton(
              shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(
                      widget.buttonRadius == null
                          ? heightTwenty
                          : widget.buttonRadius)),
              color: widget.color == null
                  ? Theme.of(context).accentColor
                  : widget.color,
              textColor: widget.textColor == null
                  ? Theme.of(context).primaryColorDark
                  : widget.textColor,
              onPressed: () => _openFileExplorer(),
              child: new Text(widget.title == null ? "Select" : widget.title),
            ),
          ),
          new Builder(
            builder: (BuildContext context) => _loadingPath
                ? Padding(
                    padding: const EdgeInsets.only(bottom: heightTen),
                    child: const CircularProgressIndicator())
                : _path != null || _paths != null
                    ? new Container(
                        padding: const EdgeInsets.only(bottom: heightThirty),
                        height: MediaQuery.of(context).size.height * 0.50,
                        child: new Scrollbar(
                            child: new ListView.separated(
                          itemCount: _paths != null && _paths.isNotEmpty
                              ? _paths.length
                              : 1,
                          itemBuilder: (BuildContext context, int index) {
                            final bool isMultiPath =
                                _paths != null && _paths.isNotEmpty;
                            final dynamic name = 'File $index: ' +
                                (isMultiPath
                                    ? _paths.keys.toList()[index]
                                    : _fileName ?? '...');
                            final path = isMultiPath
                                ? _paths.values.toList()[index].toString()
                                : _path;

                            return new ListTile(
                              title: new Text(
                                name,
                              ),
                              subtitle: new Text(path),
                            );
                          },
                          separatorBuilder: (BuildContext context, int index) =>
                              new Divider(),
                        )),
                      )
                    : new Container(),
          ),
        ],
      ),
    );
  }
}
